@@ -346,6 +346,27 @@ int gfal2_bring_online(gfal2_context_t context, const char* url,
                        int async,
                        GError ** err);
 
+/**
+ * @brief Bring online a file
+ *
+ * @param context : gfal2 handle, see \ref gfal2_context_new
+ * @param url : url of the file
+ * @param metadata : Staging metadata
+ * @param pintime : pin time
+ * @param timeout : timeout
+ * @param token : The token will be put in the buffer pointed by this
+ * @param tsize :  The size of the buffer pointed by token
+ * @param async : Asynchronous request (does not block if != 0)
+ * @param err : GError error report
+ * @return 0 if the request has been queued, > 0 if the file is pinned, < 0 on error
+ */
+int gfal2_bring_online_v2(gfal2_context_t context,
+                               const char* url, const char* metadata,
+                               time_t pintime, time_t timeout,
+                               char* token, size_t tsize,
+                               int async,
+                               GError ** err);
+
 /**
  * @brief Check for a bring online request
  *
@@ -476,6 +497,29 @@ int gfal2_bring_online_list(gfal2_context_t context, int nbfiles, const char* co
                        int async,
                        GError ** errors);
 
+/**
+ * @brief Bring online a file
+ *
+ * @param context : gfal2 handle, see \ref gfal2_context_new
+ * @param nbfiles : number of files
+ * @param urls : urls of files
+ * @param metadata : Staging metadata array
+ * @param pintime : pin time
+ * @param timeout : timeout
+ * @param token : The token will be put in the buffer pointed by this
+ * @param tsize : The size of the buffer pointed by token
+ * @param async : Asynchronous request (does not block if != 0)
+ * @param errors : Preallocated array of nbfiles pointers to GError. User must allocate and free.
+ * @return 0 if the request has been queued, > 0 if the file is pinned, < 0 on error
+ * @note  Even if the result is > 0, you need to check each individual file status
+ */
+int gfal2_bring_online_list_v2(gfal2_context_t context, int nbfiles,
+                               const char* const* urls, const char* const* metadata,
+                               time_t pintime, time_t timeout,
+                               char* token, size_t tsize,
+                               int async,
+                               GError ** errors);
+
 /**
  * @brief Check for a bring online request
  *
